@@ -1,6 +1,6 @@
 package CPAN::ReleaseHistory;
 {
-  $CPAN::ReleaseHistory::VERSION = '0.01';
+  $CPAN::ReleaseHistory::VERSION = '0.02';
 }
 
 use 5.006;
@@ -79,6 +79,8 @@ sub _transform_and_cache
     my ($self, $filename) = @_;
     my ($in_fh, $out_fh);
     local $_;
+    my @lines;
+    my ($distinfo, $distname);
 
     open($in_fh,  '<:gzip', $filename);
     open($out_fh, '>',      $self->path);
@@ -88,14 +90,35 @@ sub _transform_and_cache
         next LINE unless m!^authors/id/!;
         next LINE if /\.(readme|meta) /;
         next LINE if m!/CHECKSUMS !;
+        next LINE unless /^\S+\s+\S+\s+\S+/;
 
+        chomp;
         s!^authors/id/!!;
 
-        print $out_fh $_;
+        my ($path, $time, $size) = split(/\s+/, $_);
+        $distinfo = CPAN::DistnameInfo->new($path);
+        $distname = defined($distinfo) && defined($distinfo->dist)
+                    ? $distinfo->dist
+                    : '';
+
+        push(@lines, [$distname, $path, $time, $size]);
+
     }
     close($in_fh);
-    close($out_fh);
     unlink($filename);
+
+    foreach my $line (sort by_dist_then_date @lines) {
+        printf $out_fh "%s %d %d\n", $line->[1], $line->[2], $line->[3];
+    }
+
+    close($out_fh);
+}
+
+sub by_dist_then_date
+{
+    return $a->[0] ne $b->[0]
+           ? $a->[0] cmp $b->[0]
+           : $a->[2] <=> $b->[2];
 }
 
 1;
@@ -106,7 +129,7 @@ CPAN::ReleaseHistory - information about all files ever released to CPAN
 
 =head1 SYNOPSIS
 
-  use CPAN::ReleaseHistory;
+  use CPAN::ReleaseHistory 0.02;
 
   my $history  = CPAN::ReleaseHistory->new();
   my $iterator = $history->release_iterator();
@@ -122,6 +145,9 @@ CPAN::ReleaseHistory - information about all files ever released to CPAN
 
 B<NOTE>: this is very much an alpha release. Any and all feedback appreciated.
 
+The internal caching format changed in 0.02, so you should make sure you have
+at least 0.02, using the C<use> line shown in the SYNOPSIS.
+
 This module provides an iterator that can be used to look at every file
 that has ever been released to CPAN, regardless of whether it is still on CPAN.
 
@@ -149,6 +175,46 @@ The number of bytes in the file.
 
 =back
 
+=head2 Be aware
+
+When iterating over CPAN's history, you'll find that most distribution names reveal
+a clean release history. For example, JUERD did two releases of L<again>,
+which I then adopted:
+
+ J/JU/JUERD/again-0.01.tar.gz
+ J/JU/JUERD/again-0.02.tar.gz
+ N/NE/NEILB/again-0.03.tar.gz
+ N/NE/NEILB/again-0.04.tar.gz
+ N/NE/NEILB/again-0.05.tar.gz
+
+But you will also discover that there are various 'anomalies' in the history of CPAN releases.
+These are usually well in the past -- PAUSE and the related toolchains have evolved to
+prevent most of these.
+For example, here's the sequence of releases for distributions called 'enum':
+
+ Z/ZE/ZENIN/enum-1.008.tar.gz
+ Z/ZE/ZENIN/enum-1.009.tar.gz
+ Z/ZE/ZENIN/enum-1.010.tar.gz
+ Z/ZE/ZENIN/enum-1.011.tar.gz
+ N/NJ/NJLEON/enum-0.02.tar.gz
+ Z/ZE/ZENIN/enum-1.013.tar.gz
+ Z/ZE/ZENIN/enum-1.014.tar.gz
+ Z/ZE/ZENIN/enum-1.015.tar.gz
+ Z/ZE/ZENIN/enum-1.016.tar.gz
+ R/RO/ROODE/enum-0.01.tar.gz
+ N/NE/NEILB/enum-1.016_01.tar.gz
+ N/NE/NEILB/enum-1.02.tar.gz
+ N/NE/NEILB/enum-1.03.tar.gz
+ N/NE/NEILB/enum-1.04.tar.gz
+ N/NE/NEILB/enum-1.05.tar.gz
+ N/NE/NEILB/enum-1.06.tar.gz
+
+The L<enum> module was first released by ZENIN, and I (NEILB) recently adopted it.
+But you'll see that there have been two other releases of other modules (with similar aims).
+
+Depending on what you're trying to do, you might occasionally be surprised by the sequence
+of version numbers and maintainers.
+
 =head1 METHODS
 
 At the moment there is only one method, to create a release iterator.
@@ -158,6 +224,13 @@ Other methods will be added as required / requested.
 
 See the SYNOPSIS.
 
+=head1 NOTES
+
+At the moment this module will use up a lot of memory: it grabs the remote BackPAN index,
+extracts the data it needs into memory, sorts it, then writes it to the local cache.
+If this is a problem then I'll look at another way of doing it. If it's a problem for you,
+then you should look at L<BackPAN::Index>.
+
 =head1 SEE ALSO
 
 L<BackPAN::Index> - creates an SQLite database of the BackPAN index,
